@@ -46,5 +46,8 @@ fn main() -> Result<()> {
     // collect recent history
     let recent = Command::collect("", 3)?;
     println!("recent:\n{:#?}", recent);
+
+    let c5 = Command::new("git ls-remote https://gitlab.com/crates-rs/reef.git HEAD").exec()?;
+    println!("{}", c5.format("%F"));
     Ok(())
 }
