@@ -86,10 +86,7 @@ impl Command {
                         self.timed_out = true;
                     }
                 };
-                match child.wait_with_output() {
-                    Ok(o) => Ok(o),
-                    Err(e) => Err(e).with_context(|| format!("{:#?}", &self)),
-                }
+                Ok(child.wait_with_output()?)
             }
             None => {
                 let mut cmd = std::process::Command::new(&self.exe_filename);
@@ -115,7 +112,7 @@ impl Command {
         let exe_filename = Command::which(&self.name)?;
         if exe_filename.exists() {
             self.exe_filename = exe_filename.to_path_buf();
-            let output = self.output().with_context(|| format!("{:#?}", &self))?;
+            let output = self.output()?;
             let command = Command {
                 exe_filename: exe_filename,
                 working_dir: match &self.working_dir {
@@ -296,6 +293,50 @@ impl Command {
                 .next()
         })
     }
+
+    pub fn format(&self, fmt: &str) -> String {
+        let duration = match self.duration {
+            Some(duration) => {
+                let ms = duration.as_millis();
+                let mut elapsed = format!("{} ms", ms);
+                if ms > 999 {
+                    if ms < 90000 {
+                        elapsed = format!("{} s", ms / 1000);
+                    } else {
+                        elapsed = format!("{} m", ms / 60000);
+                    }
+                }
+                elapsed
+            }
+            None => format!(""),
+        };
+        let cur_dir = match &self.working_dir {
+            Some(dir) => format!("{}", dir.display()),
+            None => "".to_string(),
+        };
+        if fmt == "%F" {
+            if cur_dir.len() > 0 {
+                format!(
+                    "{} {} {} ({},{})",
+                    &self.status(),
+                    &self.name().yellow().bold(),
+                    &self.args.join(" "),
+                    cur_dir.white().bold(),
+                    duration.white().bold(),
+                )
+            } else {
+                format!(
+                    "{} {} {} ({})",
+                    &self.status(),
+                    &self.name().yellow().bold(),
+                    &self.args.join(" "),
+                    duration.white().bold(),
+                )
+            }
+        } else {
+            format!("{}", self)
+        }
+    }
 }
 
 impl Display for Command {
